FigmaBarAdapter class

An adapter that provides navigation bar capabilities for Figma nodes.

Mixed-in types

Constructors

FigmaBarAdapter(Node node, FigmaBarType barType)
const

Properties

barType → FigmaBarType
final
children → List<Node?>?
The children of the bar
no setter
counterAxisAlignItems → CounterAxisAlignItems?
The counter axis alignment of children
no setter
defaultHeight → double
Gets the default height for this type of bar
no setter
effects → List<Effect>?
The visual effects applied to the bar
no setter
figmaHeight → double?
Gets the height from Figma design if available
no setter
fills → List<Paint>?
The fill properties of the bar
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → double
Gets the actual height to use for the bar
no setter
layoutMode → LayoutMode?
The layout mode of the bar (typically horizontal)
no setter
node → Node
final
primaryAxisAlignItems → PrimaryAxisAlignItems?
The primary axis alignment of children
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokes → List<Paint>?
The stroke properties of the bar
no setter
strokeWeight → double?
The stroke weight of the bar
no setter
supportsBar → bool
Whether the node supports navigation bar capabilities
no setter

Methods

clearCache() → void
inherited
getCached<T>(String key, T compute()) → T
inherited
getCacheId() → String
override
getCrossAxisAlignment() → CrossAxisAlignment
Gets the appropriate cross alignment for the bar content
getMainAxisAlignment() → MainAxisAlignment
Gets the appropriate alignment for the bar content
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validateBar() → void
Validates that the node supports bar capabilities

Operators

operator ==(Object other) → bool
The equality operator.
inherited