FigmaComponentAdapter class

A class that adapts a Figma component node to a more usable format.

Implementers

Constructors

FigmaComponentAdapter(Node node)
Creates an instance of FigmaComponentAdapter.
const

Properties

borderRadius → BorderRadius
Returns the BorderRadius of the component.
no setter
bottomBorderWidth → double
Returns the component's bottom border width.
no setter
colors → List<Color>
Returns a list of Colors representing the component's fills.
no setter
fontFamily → String?
Returns the component's font family.
no setter
fontSize → double?
Returns the component's font size.
no setter
fontStyle → FontStyle?
Returns the component's text FontStyle.
no setter
fontWeight → FontWeight?
Returns the component's FontWeight.
no setter
gradients → List<Gradient>
Returns the component's Gradients.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
Returns the component ID.
no setter
imageFilters → List<ImageFilter>
no setter
isVisible → bool
Returns true when the component is visible.
no setter
leftBorderWidth → double
Returns the component's left border width.
no setter
letterSpacing → double?
Returns the component's letter spacing.
no setter
lineHeight → double?
Returns the component's line height.
no setter
name → String
Returns the component name.
no setter
node → Node
The Figma node representing the component.
final
opacity → double
Returns the opacity of the component.
no setter
padding → EdgeInsets
Returns the component's padding.
no setter
rightBorderWidth → double
Returns the component's right border width.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadows → List<BoxShadow>
Returns the component's BoxShadows.
no setter
shape → BoxShape
The shape type of the node
no setter
size → Size
Returns the component's size.
no setter
strokeAlignment → double
Returns the component's stroke alignment.
no setter
strokes → List<Color>
Returns a list of Colors representing the component's strokes.
no setter
topBorderWidth → double
Returns the component's top border width.
no setter
type → String
Returns the component type.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited