FigmaVectorAdapter class

An adapter that provides vector capabilities for Figma nodes. This adapter handles both vector nodes and components that can behave as vectors.

Constructors

FigmaVectorAdapter(Node node)
const

Properties

effects → List<Effect>?
The visual effects applied to the vector
no setter
fillGeometry → List<Path>?
The fill geometry of the vector
no setter
fills → List<Paint>?
The fill properties of the vector
no setter
hashCode → int
The hash code for this object.
no setterinherited
node → Node
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowPadding → EdgeInsets
The extra padding needed for shadows
no setter
size → Size
The size of the vector
no setter
strokeGeometry → List<Map<String, dynamic>>?
The stroke geometry of the vector
no setter
strokes → List<Paint>?
The stroke properties of the vector
no setter
strokeWeight → double?
The stroke weight of the vector
no setter
supportsVector → bool
Whether the node supports vector capabilities
no setter

Methods

getFillPaths() → List<String>
Gets the path data for painting
getStrokePaths() → List<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validateVector() → void
Validates that the node supports vector capabilities and throws a descriptive error if it doesn't.

Operators

operator ==(Object other) → bool
The equality operator.
inherited