MorphrCloudOptions class

Constructors

MorphrCloudOptions({required String projectId, required String endpoint, required String clientId, required String clientSecret})
const

Properties

clientId → String
final
clientSecret → String
final
endpoint → String
final
hashCode → int
The hash code for this object.
no setterinherited
projectId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited