MorphrFileStorage class

Constructors

MorphrFileStorage({required String fileName})

Properties

fileName → String
final
hashCode → int
The hash code for this object.
no setterinherited
localPath → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBackup() → Future<String?>
exists() → Future<bool>
init() → Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readAsString() → Future<String>
toString() → String
A string representation of this object.
inherited
writeAsString(String content) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited