FigmaScaffoldComponent class

A component that renders a Figma design as a Flutter Scaffold.

This component handles the correct placement of special UI elements like AppBar, BottomNavigationBar, and FloatingActionButton into the appropriate positions within a Scaffold, while rendering the remaining content as the body.

Inheritance

Constructors

FigmaScaffoldComponent(String? bodyNodeName, {String? appBarNodeName, String? bottomBarNodeName, String? floatingActionButtonNodeName, List<NodeTransformer> appBarTransformers = const [], List<NodeTransformer> bodyTransformers = const [], List<NodeTransformer> bottomBarTransformers = const [], List<NodeTransformer> fabTransformers = const [], Color? backgroundColor, FloatingActionButtonLocation? floatingActionButtonLocation, Key? key})
Creates a FigmaScaffoldComponent.
const

Properties

appBarNodeName → String?
The name of the node in Figma that should be rendered as an AppBar.
final
appBarTransformers → List<NodeTransformer>
Transformers to apply to the AppBar node.
final
backgroundColor → Color?
Background color for the Scaffold.
final
bodyNodeName → String?
The name of the node in Figma that should be rendered as the main content.
final
bodyTransformers → List<NodeTransformer>
Transformers to apply to the body node.
final
bottomBarNodeName → String?
The name of the node in Figma that should be rendered as a BottomNavigationBar.
final
bottomBarTransformers → List<NodeTransformer>
Transformers to apply to the bottom bar node.
final
fabTransformers → List<NodeTransformer>
Transformers to apply to the floating action button node.
final
floatingActionButtonLocation → FloatingActionButtonLocation?
FloatingActionButton position.
final
floatingActionButtonNodeName → String?
The name of the node in Figma that should be rendered as a FloatingActionButton.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited