Morph class

A class that represents a given Figma component.

Inheritance

Constructors

Morph(Node node)
const

Properties

borderRadius → BorderRadius
Returns the BorderRadius of the component.
no setterinherited
bottomBorderWidth → double
Returns the component's bottom border width.
no setterinherited
colors → List<Color>
Returns a list of Colors representing the component's fills.
no setterinherited
fontFamily → String?
Returns the component's font family.
no setterinherited
fontSize → double?
Returns the component's font size.
no setterinherited
fontStyle → FontStyle?
Returns the component's text FontStyle.
no setterinherited
fontWeight → FontWeight?
Returns the component's FontWeight.
no setterinherited
gradients → List<Gradient>
Returns the component's Gradients.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
Returns the component ID.
no setterinherited
imageFilters → List<ImageFilter>
no setterinherited
isVisible → bool
Returns true when the component is visible.
no setterinherited
leftBorderWidth → double
Returns the component's left border width.
no setterinherited
letterSpacing → double?
Returns the component's letter spacing.
no setterinherited
lineHeight → double?
Returns the component's line height.
no setterinherited
name → String
Returns the component name.
no setterinherited
node → Node
The Figma node representing the component.
finalinherited
opacity → double
Returns the opacity of the component.
no setterinherited
padding → EdgeInsets
Returns the component's padding.
no setterinherited
rightBorderWidth → double
Returns the component's right border width.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadows → List<BoxShadow>
Returns the component's BoxShadows.
no setterinherited
shape → BoxShape
The shape type of the node
no setterinherited
size → Size
Returns the component's size.
no setterinherited
strokeAlignment → double
Returns the component's stroke alignment.
no setterinherited
strokes → List<Color>
Returns a list of Colors representing the component's strokes.
no setterinherited
topBorderWidth → double
Returns the component's top border width.
no setterinherited
type → String
Returns the component type.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited