MorphrService class

Properties

hashCode → int
The hash code for this object.
no setterinherited
isCloudEnabled → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
getComponent(String componentId) → Node?
initialize({required String documentPath}) → Future<void>
initializeCloud({required MorphrCloudOptions options}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reload() → Future<void>
resetCloudToAsset() → Future<void>
syncCloud() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → MorphrService
final