FigmaTreeRenderer class

A renderer that can recursively render a Figma node tree into Flutter widgets.

This renderer automatically determines the type of each node and renders it appropriately, including its children.

Constructors

FigmaTreeRenderer()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render({required Node node, required BuildContext context, List<NodeTransformer> transformers = const [], Node? parent, TransformerManager? transformerManager}) → Widget
Renders a Figma node and all its children recursively.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited